#!/bin/sh
# :
#
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.0.6 Mon Mar 22 12:25:19 PST 1999 bpowell; chmod 1777 doesn't
# always work in solaris 2.6 and newer since /tmp has the setgid bit set
# see man chmod in 2.6 for details. Thus we do a g-s before the chmod 1777 to fix. 

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`

OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

Intro() {

cat << EOF

 This program creates /etc/rc.d/rc3.d/S79tmpfix so that upon boot the /tmp
 directory will always have the sticky bit set mode 1777

EOF

}

CheckPS() {

if [ -f /etc/rc.d/rc3.d/S??tmpfix ]; then
   t_echo 2 " File /etc/rc.d/rc3.d/S??tmpfix already exists - Checking config"
   grep "/bin/chmod 1777 /tmp" /etc/rc.d/rc3.d/S??tmpfix >/dev/null
   if [ $? -eq 0 ]; then
   t_echo 2 "        Everything looks good mode 1777 for /tmp - PASSES CHECK"
   else
   t_echo 0 "        Could not locate chmod 1777 /tmp - FAILS CHECK"
   t_echo 2 "        Run with -[Ff] option to fix"
   exit 1
   fi
else
   t_echo 0 "       Could not find /etc/rc.d/rc3.d/S??tmpfix - FAILS CHECK"
   t_echo 2 "       Run with -[Ff] option to fix"
   exit 1
fi
}

FixPS() {
if [ -f /etc/rc.d/rc3.d/S??tmpfix ]; then
   t_echo 2 " File /etc/rc.d/rc3.d/S??tmpfix already exists; exiting"
   exit 1
else 
   t_echo 0 " Creating /etc/rc.d/rc3.d/S79tmpfix..."

/bin/cat << EOF >/etc/rc.d/rc3.d/S79tmpfix
#!/bin/sh
#ident  "@(#)tmpfix 1.0    95/09/14"
 
if [ -d /tmp ]
then
/bin/chmod g-s /tmp
/bin/chmod 1777 /tmp
/bin/chgrp root /tmp
/bin/chown root /tmp
fi
EOF

    /bin/chmod 755 /etc/rc.d/rc3.d/S79tmpfix
   t_echo 2 " File /etc/rc.d/rc3.d/S79tmpfix created"
fi

}

action=$1
case ${action} in
	-[Ii]*)
	Intro
	;;
	-[Ff]*)
	FixPS
	;;
	-[Vv]*)
	CheckPS
	;;
	*)
        t_echo 1 "       ERROR:Invalid arg $action"
        t_echo 1 "       ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
;;
esac


# List all files to save prior to changes this modules might make.
# Syntax is SAVEFILES='foo bar foobar'
#
SAVEFILES='/etc/rc.d/rc3.d/S79tmpfix'
