:
# sendmail-forward.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
#
 
TITANHOME=`pwd`
MYNAME=`basename $0`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/mail/sendmail.cf /usr/local/forward'
RUNDATE=`/usr/bin/date +%Y%m%d%H%M`
OS=`uname -r`
FORWARDDIR="/usr/local/forward"
EXFORWARDDIR="\/usr\/local\/forward"
SENDMAILCONF="/etc/mail/sendmail.cf"

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

if [ -x /usr/bin/nawk ];then
AWK=/usr/bin/nawk
elif [ -x /usr/bin/awk ];then
AWK=/usr/bin/awk
fi

# from michael@netsys.co.nz 
# check to see if sendmail version isn't too old for the script
if grep DVSMI-SVR4  /etc/mail/sendmail.cf > /dev/null ; then
  t_echo 1 "$MYNAME : ERROR - sendmail isn't patched!!"       
        exit 1                                                
fi           

Intro() {
cat << EOF_INTRO
 $MYNAME - This script checks for restricted forwarding in the sendmail 
 conf file, and restrict forward files to sysadmin controlled directory,
 by default $FORWARDDIR is used. It will also check the permissions of 
 the directory to make sure it is really restricted.

EOF_INTRO
}

Check() {

   if grep "^[^#]*ForwardPath\=${FORWARDDIR}\/\.forward\.\$u[ ]*$" \
        $SENDMAILCONF ;then
        t_echo 1 "  forwarding restricted to $FORWARDDIR - PASSES CHECK "
   else
        t_echo 0 "  forwarding NOT restricted to $FORWARDDIR - FAILS CHECK "
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (sendmail-forward.sh -f) Also see nuke-sendmail.sh. For"
        t_echo 3 "those systems configured to be sendmail servers, configure sendmail to not"
        t_echo 3 "forward mail to files outside of a controlled location. Restricts forwarding in"
        t_echo 3 "the sendmail conf file, and restrict forward files to sysadmin controlled"
        t_echo 3 "directory, by default /usr/local/forward is used. It will also check the"
        t_echo 3 "permissions of the directory to make sure it is really restricted."        t_echo 3 " "
        t_echo 3 "======================================================================== "

   fi

   if [ -d "$FORWARDDIR" ];then
     /usr/bin/ls -ld $FORWARDDIR 2> /dev/null | $AWK '{
                        if ($1 != "drwxr-xr-x" ) {
                        exit 1;
                                }
                        if ($3 != "root" ) {
                        exit 1;
                                }
                        if ($4 != "sys" ) {
                        exit 1;
                                }
                      }'

      if [ $? -ne 0 ];then
       t_echo 0 "  $FORWARDDIR params - FAILS CHECK"
      else
        t_echo 1 "  $FORWARDDIR params - PASSES CHECK "
      fi
   else  
     t_echo 0 "  $FORWARDDIR missing - FAILS CHECK"
   fi

}


Fix() {

  if [ -d "$FORWARDDIR" ];then
    /usr/bin/ls -ld $FORWARDDIR 2> /dev/null | $AWK '{
                        if ($1 != "drwxr-xr-x" ) {
                        exit 1;
                                }
                        if ($3 != "root" ) {
                        exit 1;
                                }
                        if ($4 != "sys" ) {
                        exit 1;
                                }
                      }'

    if [ $? -ne 0 ];then
       t_echo 0 "  $FORWARDDIR params - FAILS CHECK . Fixing now..."
     if chmod 0755 "$FORWARDDIR" && \
       chown root "$FORWARDDIR" && chgrp sys "$FORWARDDIR" \
       > /dev/null 2>&1; then
       t_echo 2 "  $FORWARDDIR params FIXED. "
     else
       t_echo 0 "  $FORWARDDIR params change FAILED "
       exit 1
     fi
    else
     t_echo 1 "  $FORWARDDIR params - PASSES CHECK "
    fi
  else  
   t_echo 2 "  $FORWARDDIR missing - Fixing now...."
   if mkdir -p "$FORWARDDIR" && chmod 0755 "$FORWARDDIR" && \
        chown root "$FORWARDDIR" && chgrp sys "$FORWARDDIR" \
       > /dev/null 2>&1; then
        t_echo 2 "  $FORWARDDIR created. "
   else 
       t_echo 0 "  $FORWARDDIR creation FAILED "
       exit 1
   fi
  fi

   if grep "^[^#]*ForwardPath\=${FORWARDDIR}\/\.forward\.\$u[ ]*$" \
        $SENDMAILCONF > /dev/null 2>&1;then
        t_echo 1 "  forwarding restricted to $FORWARDDIR : PASSES CHECK "
   else
        t_echo 2 "  forwarding NOT restricted to $FORWARDDIR : Fixing now.. "
	ed - $SENDMAILCONF <<- EOED
	g/^[^#]*ForwardPath[ ]*\=/s/[ ]*\=.*/\=${EXFORWARDDIR}\/\.forward\.\$u/g
	.
	w
	q
	EOED
   fi
   if grep "^[^#]*ForwardPath\=${FORWARDDIR}\/\.forward\.\$u[ ]*$" \
        $SENDMAILCONF > /dev/null 2>&1;then :
   else
        t_echo 0 "  forwarding NOT restricted to $FORWARDDIR - ERROR FIX FAILED "
   fi

}

 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        echo "        ERROR:Invalid arg $action"
        echo "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        echo " "
;;
esac

