:
# adjust-arp-timers.sh
# version 3.0.1 Tue Dec  1 09:23:31 PST 1998 bpowell
# version 3.0.3 Tue Fri Jan  8 12:42:25 PST 1999 bpowell; for FILE loop in Fix()
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 3.6 Wed April 19 18:20:18 PST 2000 ndd name changes for solaris 8
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 
#

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/rc2.d/S??inet'

OS=`uname -r`

#
# suck in some lib functions (t_echo, etc.)
#
. misc_functions.sh

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

case "`uname -r`" in
5.[234567]*) ;;
*)
        t_echo 1 "$MYNAME : ERROR - This script is not needed in solaris 8 and newer"
        t_echo 1 "please use adjust-arp-timers2.8.sh instead"
        exit 1;;
esac

Intro() {
cat << EOF

 $MYNAME : This changes the system configuration to shorten the 
 ARP expiration timer to one minute instead of the default 20 minutes. This 
 stops some of the ARP hijacking and ARP spoofing attacks. A better solution 
 is still to use encrypted sessions, as they are harder to hijack/spoof.

 The program modifies /etc/rc2.d/S??inet adding in the lines:

	ndd -set /dev/ip ip_ire_flush_interval 60000    /* 1 min */
	ndd -set /dev/arp arp_cleanup_interval 60000    /* 1 min */


EOF

}

Fix() {
	if [ -f /etc/rc2.d/S??inet -o /etc/rc3.d/S??inet ]; then
	for FILE in `ls /etc/rc*.d/S??inet`
	do
	egrep '(ip_ire_flush_interval|arp_cleanup_interval)' $FILE >/dev/null 2>&-

	if [ $? -eq 0 ]; then
   	t_echo 1 "Entries for ARP in S??inet exist - PASSES CHECK"
 	else
   	t_echo 2 "Entries for ARP in S??inet do not exist - Fixing "

        t_echo 2 " Adding lines"
	t_echo 2 " ndd -set /dev/ip ip_ire_flush_interval 60000"
   	t_echo 2 " ndd -set /dev/arp arp_cleanup_interval 60000"
   	t_echo 2 " to /etc/rc2.d/S??inet"
   	t_echo 2 "    "

ed - $FILE <<- !
a
	ndd -set /dev/ip ip_ire_flush_interval 60000
.
w
a
	ndd -set /dev/arp arp_cleanup_interval 60000
.
w
q
!
fi
done
fi
}

Check() {
if [ -f /etc/rc2.d/S??inet ]; then
  t_echo 2 "    "
  t_echo 3 "    Checking for ARP timers in /etc/rc2.d/S??inet"
  t_echo 3 "    "
  egrep '(ip_ire_flush_interval|arp_cleanup_interval)' /etc/rc2.d/S??inet >/dev/null 2>&-
  if [ $? -eq 0 ]; then
  t_echo 3 "    "
  t_echo 1 "        ARP timers have been set - PASSES CHECK"
  t_echo 2 "    "
  else
  t_echo 0 "        ARP timers are not set - FAILS CHECK"
  t_echo 2 "    "
 fi
 else
  t_echo 1 "No file /etc/rc2.d/S??inet found - ERROR "
fi
}

action=$1
case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	Check
	Fix
	;;
	-[Vv]*)
	Check
	;;
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
;;
esac
