:
# disable-services.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 4.1 Jul  5 11:44:44 EDT 2000 by Ray Barta
# Removes services based on RC directories ($RCDIRS) and services ($DISABLERC)
# Places a small s in the front of the service to disable it.
# version 4.0.beta1

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt
# Archibald, and Dan Farmer 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with
# respect to its usage or its effect upon hardware or computer
# systems, and maintains copyright as set out in the "LICENSE"
# document which accompanies distribution.
 
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
# Changed nfs.server (runs from S15 now) and S76snmpdx now runs from rc3.d
SAVEFILES='/etc/rc2.d/S73nfs.client /etc/rc2.d/S74autofs /etc/rc2.d/S80lp /etc/rc2.d/S88sendmail /etc/rc2.d/S71rpc /etc/rc2.d/S99dtlogin /etc/rc3.d/S15nfs.server /etc/rc3.d/S76snmpdx'

. misc_functions.sh

#
# Directory containing run levels
#
RCDIRS="/etc/rc2.d /etc/rc3.d"
#
# Services to disable (Will check for service under each directory in $RCDIRS) 
# Modify/Add to disable any aditional services
#
DISABLERC="S73nfs.client S74autofs S80lp S88sendmail S71rpc S99dtlogin S15nfs.server S76snmpdx"

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

Intro() {
cat << EOF_INTRO
 
 $MYNAME - This script checks and turns off specific services. 
 It replaces the "S" for "Start" with a  small "s" in front of the 
 file to keep the file from running.

 It checks the following directories
 $RCDIRS

 and checks/moves the following services
 $DISABLERC

EOF_INTRO
}

Check() {

for service in $DISABLERC; do
	RESULT=""
	for dir in $RCDIRS; do
		if [ -f $dir/$service ]; then
			RESULT="Service $service still active in $dir - FAILS CHECK"
	t_echo 3 " "
	t_echo 3 "Titan Recommendation: (disable-services.sh -f) Disable NFS server, NFS client,"
	t_echo 3 "and *RPC on all systems that don't require them. "
	t_echo 3 "Note - RPC is required on HA systems. Use Ipfilter or EFS Lite to restrict RPC on"
	t_echo 3 "these networks. "
	t_echo 3 " "
	t_echo 3 "============================================================== "

		fi
	done
	if [ -z "${RESULT}" ]; then
		t_echo 1 "Service $service disabled - PASSES CHECK"
	else
		t_echo 1 "${RESULT}"
	fi
done

}

Fix() {

for service in $DISABLERC; do
	RESULT=""
	for dir in $RCDIRS; do
		if [ -f $dir/$service ]; then
			SERVICE=`basename $dir/$service`
			RESULT="Moving $dir/$SERVICE to $dir/s$SERVICE"
			mv $dir/$SERVICE `echo $dir/$SERVICE | tr -s S s`
		fi
	done
	if [ -z "${RESULT}" ]; then
		t_echo 1 "Service $service disabled - PASSES CHECK"
	else
		t_echo 0 "${RESULT}"
	fi
done

}


 
action=$1
case $action in
 -[Ff]*)
Fix
;;
 -[Vv]*)
Check
;;
 -[Ii]*)
Intro
;;
 
*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 
        t_echo 1 " "
;;
esac

