:
# disable_ip_holes.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.0.3  Fri Jan  8 12:42:25 PST 1999 bpowell; for FILE loop in Fix()
# version 3.0.5  Thu Mar 11 08:51:52 PST 1999 bpowell; Sun changed syntax of S69inet
# Check() was not finding "ip_forwarding 1" because it is now a variable "$forwarding"
# changed the check() to no longer even look at the S69inet file; just the kernel settings
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/usr/sbin:/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/notrouter /etc/rc2.d/S??inet /etc/rc3.d/S??inet'
OS=`uname -r`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME - This disables source routing and IP forwarding at
 boot time. This program modifies /etc/rc2.d/S??inet overruling
 the default settings listed in S69inet, with the following lines:

	 ndd -set /dev/ip ip_forward_src_routed 0
	 ndd -set /dev/ip ip_forwarding 0
	 ndd -set /dev/ip ip_forward_directed_broadcasts 0
	 ndd -set /dev/ip ip_ignore_redirect 1
	 ndd -set /dev/ip ip_strict_dst_multihoming 1

 We also touch /etc/notrouter in the Fix mode

Note: On FW-1 systems on rare occasions you might want to leave ip_forward on.
      However in production enviornments the source routing should always be off.

Note2: On clustered systems you may need to reset ip_strict_dst_multihoming back to
       0. This is not too much of a concern assuming your cluster is not exposed to 
       the Internet or another hostile network where IP spoofing may ocure, as your
       firewall should be blocking spoofed addresses from the outside networks. 

EOF
}

Check() {
t_echo 2 " Checking kernel settings using ndd"

SOURCE=` ndd /dev/ip ip_forward_src_routed`
	t_echo 3 "IP source routing is currently set to $SOURCE"
	if [ $SOURCE != 0 ] ; then 
		t_echo 0 " System allows source routed packet forwarding - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (disable_ip_holes.sh -f) Disable ip_src_routed, broadcast,"
        t_echo 3 "and use strict multihoming. Add to /etc/rc2.d/S69inet: "
        t_echo 3 "  "
        t_echo 3 "    ndd -set /dev/ip ip_forward_src_routed 0 "
        t_echo 3 "    ndd -set /dev/ip ip_forwarding 0 "
        t_echo 3 "    ndd -set /dev/ip ip_forward_directed_broadcasts 0 "
        t_echo 3 "    ndd -set /dev/ip ip_ignore_redirect 1 "
        t_echo 3 "    ndd -set /dev/ip ip_strict_dst_multihoming 1 "
        t_echo 3 " "
        t_echo 3 "======================================================================== "

	else
		t_echo 1 " System set to not forward source routed packets - PASSES CHECK"
	fi

FORWARD=` ndd /dev/ip ip_forwarding`
        t_echo 3 "IP forwarding is currently set to $FORWARD" 
        if [ $FORWARD != 0 ] ; then  
                t_echo 0 " System forwards IP packets - FAILS CHECK" 
        else    
                t_echo 1 " System does not Forward IP packets - PASSES CHECK"
        fi

FORWARD2=` ndd /dev/ip ip_forward_directed_broadcasts`
        t_echo 3 "IP forwarding directed broadcast is currently set to $FORWARD2" 
        if [ $FORWARD2 != 0 ] ; then  
                t_echo 0 " System allows forwarding of directed broadcasts - FAILS CHECK" 
        else    
                t_echo 1 " System does not forward directed broadcast packets - PASSES CHECK"
        fi

IGNORE=` ndd /dev/ip ip_ignore_redirect`
        t_echo 3 "IP ignore redirect is currently set to $IGNORE" 
        if [ $IGNORE != 1 ] ; then  
                t_echo 0 " System is not set to ignore redirected packets - FAILS CHECK" 
        else    
                t_echo 1 " System is set to ignore redirected packets - PASSES CHECK"
        fi

STRICT=` ndd  /dev/ip ip_strict_dst_multihoming`
        t_echo 3 "IP strict multihoming is currently set to $STRICT" 
        if [ $STRICT != 1 ] ; then  
                t_echo 0 " System is not set to do strict destination multihoming - FAILS CHECK" 
        else    
                t_echo 1 " System is set to do strict multihoming  - PASSES CHECK"
        fi

}

Check2() {
   if [ -f /etc/notrouter ]; then
 t_echo 1 "         System configured as 'notrouter' - PASSES CHECK"
        else
 t_echo 0 "         /etc/notrouter does not exist - FAILS CHECK"
        fi
 
}


Fix() {
t_echo 0 " Disabling ip_forward, source_route, forward_broadcast "
t_echo 0 " and setting strict_multihoming in /etc/rc2.d/S??inet"
t_echo 2  "  "

if [ -f /etc/rc2.d/S??inet -o /etc/rc3.d/S??inet ]; then
for FILE in `ls /etc/rc*.d/S??inet`
do
 egrep '(src_routed 0|ignore_redirect 1|broadcasts 0|multihoming 1)' $FILE >/dev/null 2>&-
 if [ $? -eq 0 ]; then
	t_echo 1 "Settings okay - PASSES CHECK"
 else
ed - $FILE << EOEF
a
	ndd -set /dev/ip ip_forwarding 0
	ndd -set /dev/ip ip_forward_src_routed 0
        ndd -set /dev/ip ip_forward_directed_broadcasts 0
	ndd -set /dev/ip ip_ignore_redirect 1
        ndd -set /dev/ip ip_strict_dst_multihoming 1

.
w
q
EOEF
fi
done
 else
 t_echo 0 "No inet startup file found - ERROR "
fi

# while we are at it lets go ahead and set the parameters now so we don't have
# to wait for the reboot
if [ -f /usr/sbin/ndd -a -x /usr/sbin/ndd ] ; then
t_echo 3 " Fixing the running kernel now"
ndd -set /dev/ip ip_forwarding 0
ndd -set /dev/ip ip_forward_src_routed 0
ndd -set /dev/ip ip_forward_directed_broadcasts 0
ndd -set /dev/ip ip_ignore_redirect 1
ndd -set /dev/ip ip_strict_dst_multihoming 1
t_echo 3 " Done setting the running kernel"
else
	t_echo 0 "Ths ndd binary could not be located - ERROR"
fi


}

Fix2() {
   if [ -f /etc/notrouter ]; then
 t_echo 1 "         System configured as 'notrouter' - PASSES CHECK"
        else
        touch /etc/notrouter
 t_echo 2 "         Created /etc/notrouter - Routing now disabled"
        fi

}

action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	Check
	Fix
	Fix2
	;;
	-[Vv]*)
	Check
	Check2
	;;
	*)
 t_echo 1 "         ERROR:Invalid arg $action"
 t_echo 1 "         ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
 t_echo 1 " "
	;;
	esac
