:
# hosts.equiv.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 4.0

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES='/etc/hosts.equiv'
HOST=`uname -n`

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi

. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME - This program looks to see if /etc/hosts.equiv exists. If run 
 in verify mode it then verifies that there are no '+' characters
 in the file and reports which, if any, hosts are allowed access.

 For all hosts allowed access, other than a '+' character,
 the host line is modified to reflect a non-compliant
 name service pattern such as 'foo' moved to '._-foo'
 and should subsequently be reviewed prior to allowing
 the entry to continue exist in /etc/hosts.equiv for
 the purposes of access control.

 If run in Fix mode it simply removes any  '+' entries

EOF

}

Fix() {

if  [ -f /etc/hosts.equiv -a -s /etc/hosts.equiv ]; then
      t_echo 2 " /etc/hosts.equiv exists and is not empty. Saving a copy..."
      cp -p /etc/hosts.equiv /etc/hosts.equiv.ORIG.$DATE

        if grep -s "^+$" /etc/hosts.equiv
        then
	ed - /etc/hosts.equiv <<- !
	g/^+$/d
	w
	q
	!
        fi
else
        t_echo 1 "        No /etc/hosts.equiv -  PASSES CHECK"
	exit 1
fi

}


Check() {

if  [ -f /etc/hosts.equiv -a -s /etc/hosts.equiv ]; then
      t_echo 2 " /etc/hosts.equiv exists and is not empty - Checking..."

      for ENTRY in `cat /etc/hosts.equiv`
        do
        grep -s "^+$ENTRY$" /etc/hosts.equiv >/dev/null 2>&-
	if [ $? -ne 0 ]; then
           t_echo 0 "       Found $ENTRY - FAILS CHECK"
        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (hosts.equiv.sh -f) Hosts.equiv allows equivilent trust"
        t_echo 3 "between your system and other systems on the network. A "+ +" entry in"
        t_echo 3 "hosts.equiv would allow anyone to modify your system files. Hosts.equiv should"     
        t_echo 3 "always be disabled. It belongs (sadly) in the past when Unix systems were able"
        t_echo 3 "to trust each other."
        t_echo 3 " "
        t_echo 3 "======================================================================== "

        fi
       done
else
        t_echo 1 "       No /etc/hosts.equiv -  PASSES CHECK"
	exit 1
fi

}


action=$1
        case ${action} in
	-[Ii]*)
	Intro
	;;
         -[Ff]*)
        Fix
        ;;
        -[Vv]*)
	Check
        ;;
        *)
        t_echo 1 "       ERROR:Invalid arg $action"
        t_echo 1 "       ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
        ;;
        esac
