:
# rhosts.sh
# version 3.0 Sep 25 11:21:02 PDT 1998
# version 3.4 Wed Feb 16 08:33:18 PST 2000 savefile variable added
# version 3.5 Thu Mar 23 13:03:28 PST 2000 fixes to keep people from
#             adding in symlinks as their .rhosts from dynamo@harvard.net
# version 3.5B fix to make sure our $target2 isn't also a symlink or already there
#             from dynamo@harvard.net also moved the rhosts to add $DATE
# version 4.0 beta1

umask 022
# This tool suite was written by and is copyrighted by Brad Powell, Matt 
# Archibald, and Dan Farmer 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001
#
# The copyright holder disclaims all responsibility or liability with 
# respect to its usage or its effect upon hardware or computer 
# systems, and maintains copyright as set out in the "LICENSE" 
# document which accompanies distribution. 

# setup
TITANHOME=`pwd`
PATH=/bin:/usr/bin:/sbin:$TITANHOME/lib
MYNAME=`basename $0`
OS=`uname -r`
DATE=`/bin/date +%m%d%y%H%M`
SAVEFILES=''

# did things work out or not?
action=`sanity_check $MYNAME $1`
if test $? -ne 0 ; then
        exit 1
        fi
. misc_functions.sh

Intro() {

cat << EOF

 $MYNAME -  This program checks rhosts entries against valid user ids
 in the NIS(+) and local password files in local home
 directories and displays the contents of each file with
 a field seperator of:

		  "---------------------------------------"

 No modifications are made to any files unless run with -f then
 the rhosts file, if found, is moved to ._rhosts.$DATE and chmod
 400 effectively shutdown access via the standard rhosts services.

EOF

}

GetPassLoc() {

for PASSFILE in `grep "^passwd" /etc/nsswitch.conf | awk -F":" '{print $2}'`
 do
  case $PASSFILE in
    nisplus)
        t_echo 2 "Running against passwd.org_dir..."
	niscat passwd.org_dir | awk -F: '{print $1}' >./USRI.$$
	niscat passwd.org_dir | awk -F: '{print $(NF-1)}' >./USRH.$$
	;;
    nis)
        t_echo 2 "Running against passwd.byname..."
	ypcat passwd.byname | awk -F: '{print $1}' >./USRI.$$
	ypcat passwd.byname | awk -F: '{print $(NF-1)}' >./USRH.$$
	;;
    files)
        t_echo 2 "Running against /etc/passwd..."
	cat /etc/passwd | awk -F: '{print $1}' >./USRI.$$
	cat /etc/passwd | awk -F: '{print $(NF-1)}' >./USRH.$$
	;;
        *)
        t_echo 2 "Passing on $PASSFILE"
	;;
  esac

  case "$1" in
	-V)
	Check
	;;
	-F)
	Fix
	;;
	*)
        t_echo 1 "        ERROR ($0) - No such arg $1... "
	exit 1
	;;
   esac
done

}

Fix() {

 paste ./USRI.$$ ./USRH.$$ | while read user dir ; do
        target=$dir/.rhosts
 	target2=$dir/._rhosts

# added in checks for symlink and destination symlinks just so users can't play
# tricks to get titan to rm/mv/chmod system files

	if [ -h $target ]; then
        t_echo 0 "TITAN Warning $target is a symlink! Someone was trying something nasty! - removing  "
	ls -ld $target
	rm $target
        fi

	if [ -h $target2 ]; then
           t_echo 0 "TITAN Warning - destination $target2 is a symlink! Someone was doing something nasty - removing"
	ls -ld $target2
	rm $target2
	fi

	if [ -f $target2 ]; then 
         t_echo 1 " TITAN Warning - $target2 already exists! - removing "
        ls -ld $target2   
        rm $target2 
	fi

# if its just a regular rhosts file; we already trashed any symlink(s) above 
	if [ -f $target -a ! -f $target2 ]; then
	mv $target $target2.$DATE
	chmod 400 $target2.$DATE
# now we make it so users can't reinstall by making rhosts a root owned directory
        mkdir $target 
        chown root $target
        touch $target/titan
        chmod 000 $target 

	t_echo 2 "---------------------------------------"
	fi

        done
}


Check() {

paste ./USRI.$$ ./USRH.$$ | while read user dir ; do
        target="$dir/.rhosts"
        target2=$dir/._rhosts

	if [ -h $target ]; then
	t_echo 0 "TITAN Warning $target is a symlink! Someone is doing something nasty! - FAILS CHECK"
	fi

        if [ -f $target ]; then
           t_echo 0 "Found $target... - FAILS CHECK"
           t_echo 1 "---------------------------------------"
	   ls -ld "$target"
           cat "$target"
           t_echo 1 "---------------------------------------"
	        t_echo 3 " "
        t_echo 3 "Titan Recommendation: (rhosts.sh -f) Rhosts allow arbitrary trust between"
        t_echo 3 "systems at the user level (including the root user). Since there is no"
        t_echo 3 "system-wide way of enforcing users to use sane rhosts entries (also see"
        t_echo 3 "pam-rhosts-2.6.sh) Titan checks for rhost entries and removes them."
        t_echo 3 " "
        t_echo 3 "======================================================================== "

	else
	 t_echo 1 "No rhosts found in $target - PASSES CHECK"
        fi

   if [ -h $target2 ]; then
        t_echo 0 "TITAN Warning destination file for fix $target2 is a symlink! Someone is trying something nasty!"
        fi

        if [ -f $target2 ]; then
           t_echo 0 "Found $target2... "
           t_echo 1 "---------------------------------------"
           ls -ld "$target2"
           cat "$target2"
           t_echo 1 "---------------------------------------"
        fi

        done
}


action=$1
	case ${action} in
	-[Ii]*)
	Intro
	;;
	 -[Ff]*)
	GetPassLoc -F
	rm ./USRI*
	rm ./USRH*
	;;
	-[Vv]*)
	GetPassLoc -V
	 rm ./USRI* 
        rm ./USRH* 
	;;
	*)
        t_echo 1 "        ERROR:Invalid arg $action"
        t_echo 1 "        ERROR:Usage $MYNAME -[ivf] (I)ntro/(V)erify/(F)ix"
        t_echo 1 " "
	;;
	esac
